import type { IConstruct } from "constructs";
import { Construct } from "constructs";
/**
 * Represents a GitHub Actions CDK Component, extending the base `Construct` class.
 *
 * The `Component` class serves as a foundational construct within GitHub Actions workflows
 * and adds unique identifiers, type metadata, and markers for internal component
 * identification.
 */
export declare class Component extends Construct {
    /**
     * Checks if an object is an instance of `Component`.
     *
     * This static method uses a unique symbol to verify if the input object has
     * been marked as a `Component`.
     *
     * @param x - The object to check.
     * @returns `true` if `x` is a `Component`; otherwise, `false`.
     */
    static isComponent(x: unknown): x is Component;
    /**
     * Initializes a new `Component` instance.
     *
     * @param scope - The scope in which this component is defined.
     * @param id - The unique identifier for this component. If not provided, an auto-generated
     * ID is used based on the component name and scope.
     */
    constructor(scope: IConstruct, id?: string);
}
